@@ -4,12 +4,10 @@ This module contains `Exception` classes that are used in Serde.
 
 from contextlib import contextmanager
 
-import six
-
 
 __all__ = [
     'ContextError',
-    'MissingDependency',
+    'MissingDependencyError',
     'SerdeError',
     'ValidationError',
 ]
@@ -45,7 +43,7 @@ class ContextError(SerdeError):
     """
 
 
-class MissingDependency(SerdeError):
+class MissingDependencyError(SerdeError):
     """
     Raised when a dependency is missing.
     """
@@ -79,7 +77,7 @@ class ValidationError(SerdeError):
             # Avoids tags which might not have `_serde_name`
             if isinstance(field, Field):
                 d = {field._serde_name: d}
-            elif isinstance(field, (six.string_types, six.integer_types)):
+            elif isinstance(field, (str, int)):
                 d = {field: d}
         return d
 
