@@ -4,12 +4,10 @@ This module contains field classes for use with `Models <serde.Model>`.
 
 import collections
 import datetime
+import decimal
 import re
 import uuid
-
-import isodate
-from six import PY3, binary_type, integer_types, text_type
-from six.moves.collections_abc import Mapping as MappingType
+from collections.abc import Mapping as MappingType
 
 from serde.exceptions import ContextError, ValidationError, add_context
 from serde.utils import is_subclass, try_lookup, zip_equal
@@ -50,7 +48,7 @@ def _resolve(thing, none_allowed=True):
     except (KeyError, TypeError):
         pass
 
-    raise TypeError('failed to resolve {!r} into a field'.format(thing))
+    raise TypeError(f'failed to resolve {thing!r} into a field')
 
 
 class _Base(object):
@@ -112,9 +110,7 @@ class _Base(object):
         """
         if hasattr(self, '_model_cls'):
             raise ContextError(
-                'attempted to use {!r} instance more than once'.format(
-                    self.__class__.__name__
-                )
+                f'attempted to use {self.__class__.__name__!r} instance more than once'
             )
         self._model_cls = model_cls
 
@@ -259,9 +255,7 @@ class Field(_Base):
         """
         value = self._instantiate(kwargs.pop(self._attr_name, None))
         if value is None:
-            raise TypeError(
-                '__init__() missing required argument {!r}'.format(self._attr_name)
-            )
+            raise TypeError(f'__init__() missing required argument {self._attr_name!r}')
         setattr(model, self._attr_name, value)
 
     def _serialize_with(self, model, d):
@@ -278,9 +272,7 @@ class Field(_Base):
         try:
             value = d[self._serde_name]
         except KeyError:
-            raise ValidationError(
-                'missing data, expected field {!r}'.format(self._serde_name)
-            )
+            raise ValidationError(f'missing data, expected field {self._serde_name!r}')
         setattr(model, self._attr_name, self._deserialize(value))
         return model, d
 
@@ -473,7 +465,7 @@ class Instance(Field):
         """
         if not isinstance(value, self.ty):
             raise ValidationError(
-                'invalid type, expected {!r}'.format(self.ty.__name__), value=value
+                f'invalid type, expected {self.ty.__name__!r}', value=value
             )
 
 
@@ -571,7 +563,7 @@ class _Container(Instance):
         """
         value = self.ty(
             (self._apply('_serialize', element) for element in self._iter(value)),
-            **self.kwargs
+            **self.kwargs,
         )
         return super(_Container, self).serialize(value)
 
@@ -585,7 +577,7 @@ class _Container(Instance):
         value = super(_Container, self).deserialize(value)
         return self.ty(
             (self._apply('_deserialize', element) for element in self._iter(value)),
-            **self.kwargs
+            **self.kwargs,
         )
 
     def normalize(self, value):
@@ -598,7 +590,7 @@ class _Container(Instance):
         value = super(_Container, self).normalize(value)
         return self.ty(
             (self._apply('_normalize', element) for element in self._iter(value)),
-            **self.kwargs
+            **self.kwargs,
         )
 
     def validate(self, value):
@@ -632,7 +624,7 @@ class _Mapping(_Container):
                 yield element
         except (AttributeError, TypeError):
             raise ValidationError(
-                'invalid type, expected {!r}'.format(self.ty.__name__), value=value
+                f'invalid type, expected {self.ty.__name__!r}', value=value
             )
 
     def _apply(self, stage, element):
@@ -698,7 +690,7 @@ class _Sequence(_Container):
                 yield element
         except TypeError:
             raise ValidationError(
-                'invalid type, expected {!r}'.format(self.ty.__name__), value=value
+                f'invalid type, expected {self.ty.__name__!r}', value=value
             )
 
     def _apply(self, stage, element):
@@ -741,7 +733,7 @@ class Deque(_Sequence):
         super(Deque, self).validate(value)
         if value.maxlen != self.maxlen:
             raise ValidationError(
-                'invalid max length, expected {}'.format(self.maxlen), value=value
+                f'invalid max length, expected {self.maxlen}', value=value
             )
 
 
@@ -818,9 +810,7 @@ class Tuple(_Sequence):
                 yield element
         except ValueError:
             raise ValidationError(
-                'invalid length, expected {} elements'.format(
-                    len(self.elements),
-                ),
+                f'invalid length, expected {len(self.elements)} elements',
                 value=value,
             )
 
@@ -837,19 +827,16 @@ def create_primitive(name, ty):
     """
     Create a primitive `Field` class.
     """
-    doc = """\
-This field represents the built-in `{ty}` type.
+    doc = f"""This field represents the built-in `{ty}` type.
 
 Args:
     **kwargs: keyword arguments for the `Field` constructor.
-""".format(
-        ty=ty
-    )
+"""
 
     def __init__(self, **kwargs):  # noqa: N807
         Instance.__init__(self, ty, **kwargs)
 
-    __init__.__doc__ = 'Create a new `{name}`.'.format(name=name)
+    __init__.__doc__ = f'Create a new `{name}`.'
 
     return type(name, (Instance,), {'__doc__': doc, '__init__': __init__})
 
@@ -859,26 +846,64 @@ Complex = create_primitive('Complex', complex)
 Float = create_primitive('Float', float)
 Int = create_primitive('Int', int)
 Str = create_primitive('Str', str)
-Bytes = create_primitive('Bytes', bytes) if bytes != str else Str
-
-try:
-    BaseString = create_primitive('BaseString', basestring)
-except NameError:
-    pass
-
-try:
-    Long = create_primitive('Long', long)
-except NameError:
-    pass
-
-try:
-    Unicode = create_primitive('Unicode', unicode)
-except NameError:
-    pass
+Bytes = create_primitive('Bytes', bytes)
 
 del create_primitive
 
 
+# A helper function...
+def round_decimal(
+    decimal_obj: decimal.Decimal, num_of_places: int = 6
+) -> decimal.Decimal:
+    return decimal_obj.quantize(decimal.Decimal(10) ** -num_of_places).normalize()
+
+
+class Decimal(Instance):
+    """
+    A `~decimal.Decimal` field.
+
+    This field serializes `~decimal.Decimal` objects as strings and
+    deserializes string representations of Decimals as `~decimal.Decimal`
+    objects.
+
+    The resolution of the decimal can be specified. When not specified, the number
+    is not rounded. When it is specified, the decimal is rounded to this number of
+    decimal places upon serialization and deserialization.
+
+    Note: When float type numbers are not rounded before serialization,
+    they will be serialized in exact form, which as they are floats,
+    is almost never the exact intended value,
+    e.g. 0.2 = 0.20000000000000000000023
+
+    Args:
+        resolution (Union[int, bool]): The number of decimal places to round to.
+        When None, rounding is disabled.
+        **kwargs: keyword arguments for the `Field` constructor.
+    """
+
+    ty = decimal.Decimal
+
+    def __init__(self, resolution=None, **kwargs):
+        super(Decimal, self).__init__(self.__class__.ty, **kwargs)
+        self.resolution = resolution
+
+    def serialize(self, value: decimal.Decimal) -> str:
+        if self.resolution is not None:
+            value = round_decimal(value, num_of_places=self.resolution)
+        return '{0:f}'.format(value)
+
+    def deserialize(self, value) -> decimal.Decimal:
+        try:
+            if self.resolution is not None:
+                return round_decimal(
+                    decimal.Decimal(value), num_of_places=self.resolution
+                )
+
+            return decimal.Decimal(value)
+        except decimal.DecimalException:
+            raise ValidationError('invalid decimal', value=value)
+
+
 class Literal(Field):
     """
     A literal field.
@@ -903,7 +928,7 @@ class Literal(Field):
         """
         if value != self.value:
             raise ValidationError(
-                'invalid literal, expected {!r}'.format(self.value), value=value
+                f'invalid literal, expected {self.value!r}', value=value
             )
 
 
@@ -975,15 +1000,15 @@ class DateTime(Instance):
         """
         if self.format == 'iso8601':
             try:
-                return isodate.parse_datetime(value)
-            except isodate.ISO8601Error:
+                return self.ty.fromisoformat(value)
+            except ValueError:
                 raise ValidationError('invalid ISO 8601 datetime', value=value)
         else:
             try:
                 return datetime.datetime.strptime(value, self.format)
             except (TypeError, ValueError):
                 raise ValidationError(
-                    'invalid datetime, expected format {!r}'.format(self.format),
+                    f'invalid datetime, expected format {self.format!r}',
                     value=value,
                 )
 
@@ -1003,15 +1028,15 @@ class Date(DateTime):
         """
         if self.format == 'iso8601':
             try:
-                return isodate.parse_date(value)
-            except isodate.ISO8601Error:
+                return self.ty.fromisoformat(value)
+            except ValueError:
                 raise ValidationError('invalid ISO 8601 date', value=value)
         else:
             try:
                 return datetime.datetime.strptime(value, self.format).date()
             except (TypeError, ValueError):
                 raise ValidationError(
-                    'invalid date, expected format {!r}'.format(self.format),
+                    f'invalid date, expected format {self.format!r}',
                     value=value,
                 )
 
@@ -1031,15 +1056,15 @@ class Time(DateTime):
         """
         if self.format == 'iso8601':
             try:
-                return isodate.parse_time(value)
-            except isodate.ISO8601Error:
+                return self.ty.fromisoformat(value)
+            except ValueError:
                 raise ValidationError('invalid ISO 8601 time', value=value)
         else:
             try:
                 return datetime.datetime.strptime(value, self.format).time()
             except (TypeError, ValueError):
                 raise ValidationError(
-                    'invalid time, expected format {!r}'.format(self.format),
+                    f'invalid time, expected format {self.format!r}',
                     value=value,
                 )
 
@@ -1064,7 +1089,7 @@ class Text(Instance):
         """
         Create a new `Text`.
         """
-        super(Text, self).__init__(text_type, **kwargs)
+        super(Text, self).__init__(str, **kwargs)
         self.encoding = encoding
         self.errors = errors
         if self.encoding is None:
@@ -1074,7 +1099,7 @@ class Text(Instance):
         """
         Normalize byte strings to unicode strings.
         """
-        if isinstance(value, binary_type):
+        if isinstance(value, bytes):
             if self.encoding is None:
                 value = value.decode(
                     encoding=self._detect(value)['encoding'], errors=self.errors
@@ -1114,9 +1139,7 @@ class Regex(Text):
         super(Regex, self).validate(value)
         if not self._compiled.match(value):
             raise ValidationError(
-                'invalid string, expected to match regex pattern {!r}'.format(
-                    self.pattern
-                ),
+                f'invalid string, expected to match regex pattern {self.pattern!r}',
                 value=value,
             )
 
@@ -1159,11 +1182,11 @@ class Uuid(Instance):
         """
         if not isinstance(value, uuid.UUID):
             input_form = None
-            if isinstance(value, text_type):
+            if isinstance(value, str):
                 input_form = 'hex'
-            elif isinstance(value, binary_type):
-                input_form = 'bytes' if PY3 or len(value) == 16 else 'hex'
-            elif isinstance(value, integer_types):
+            elif isinstance(value, bytes):
+                input_form = 'bytes'
+            elif isinstance(value, int):
                 input_form = 'int'
             elif isinstance(value, (list, tuple)):
                 input_form = 'fields'
@@ -1208,16 +1231,13 @@ def create_from(foreign, name=None, human=None):
     if human is None:
         human = suffix
 
-    doc = """\
-A text field that asserts the text is a valid {}.
+    doc = f"""A text field that asserts the text is a valid {human}.
 
-The validation is delegated to `{}`.
+The validation is delegated to `{foreign}`.
 
 Args:
     **kwargs: keyword arguments for the `Field` constructor.
-""".format(
-        human, foreign
-    )
+"""
 
     field_cls = type(name, (Text,), {'__doc__': doc})
 
@@ -1228,7 +1248,7 @@ Args:
     def validate(self, value):
         super(field_cls, self).validate(value)
         if not self._validator(value):
-            raise ValidationError('invalid {}'.format(human), value=value)
+            raise ValidationError(f'invalid {human}', value=value)
 
     field_cls.__init__ = __init__
     field_cls.validate = validate
@@ -1275,21 +1295,7 @@ _FIELD_CLASS_MAP = {
     datetime.time: Time,
     # Others
     uuid.UUID: Uuid,
+    decimal.Decimal: Decimal,
 }
 
-try:
-    _FIELD_CLASS_MAP[basestring] = BaseString
-except NameError:
-    pass
-
-try:
-    _FIELD_CLASS_MAP[long] = Long
-except NameError:
-    pass
-
-try:
-    _FIELD_CLASS_MAP[unicode] = Unicode
-except NameError:
-    pass
-
 __all__ = [name for name, obj in globals().items() if is_subclass(obj, Field)]
