@@ -5,14 +5,10 @@ This module contains tag classes for use with `Models <serde.Model>`.
 from collections import OrderedDict
 
 from serde import fields, utils
-from serde.exceptions import (
-    DeserializationError,
-    SerializationError,
-    map_errors
-)
+from serde.exceptions import ValidationError
 
 
-class Tag(fields.BaseField):
+class Tag(fields._Base):
     """
     A tag field for a `Model <serde.Model>`.
 
@@ -33,10 +29,7 @@ class Tag(fields.BaseField):
         """
         Create a new `Tag`.
         """
-        super(Tag, self).__init__(
-            serializers=serializers,
-            deserializers=deserializers
-        )
+        super(Tag, self).__init__(serializers=serializers, deserializers=deserializers)
         self.recurse = recurse
 
     def variants(self):
@@ -63,9 +56,9 @@ class Tag(fields.BaseField):
             variant (Model): the model class.
 
         Returns:
-            tag: the corresponding tag value.
+            str: the corresponding tag value.
         """
-        return variant.__name__
+        return f'{variant.__module__}.{variant.__qualname__}'
 
     def lookup_variant(self, tag):
         """
@@ -92,15 +85,8 @@ class Tag(fields.BaseField):
         Deserialize a tag value into a Model variant.
         """
         variant = self.lookup_variant(value)
-
         if not variant:
-            raise DeserializationError(
-                'no variant found for tag {!r}'.format(value),
-                value=value,
-                field=self,
-                model_cls=self.__model__
-            )
-
+            raise ValidationError('no variant found', value=value)
         return variant
 
 
@@ -114,15 +100,7 @@ class External(Tag):
         Serialize the model variant by externally tagging the given dictionary.
         """
         variant = model.__class__
-
-        with map_errors(
-            SerializationError,
-            value=variant,
-            field=self,
-            model_cls=model.__class__
-        ):
-            d = OrderedDict([(self._serialize(variant), d)])
-
+        d = OrderedDict([(self._serialize(variant), d)])
         return d
 
     def _deserialize_with(self, model, d):
@@ -132,18 +110,9 @@ class External(Tag):
         try:
             tag = next(iter(d))
         except StopIteration:
-            raise DeserializationError(
-                'expected externally tagged data',
-                field=self
-            )
+            raise ValidationError('missing data, expected externally tagged data')
 
-        with map_errors(
-            DeserializationError,
-            value=tag,
-            field=self,
-            model_cls=model.__class__
-        ):
-            model.__class__ = self._deserialize(tag)
+        model.__class__ = self._deserialize(tag)
 
         return model, d[tag]
 
@@ -168,15 +137,7 @@ class Internal(Tag):
         Serialize the model variant by internally tagging the given dictionary.
         """
         variant = model.__class__
-
-        with map_errors(
-            SerializationError,
-            value=variant,
-            field=self,
-            model_cls=model.__class__
-        ):
-            d[self.tag] = self._serialize(variant)
-
+        d[self.tag] = self._serialize(variant)
         return d
 
     def _deserialize_with(self, model, d):
@@ -186,18 +147,9 @@ class Internal(Tag):
         try:
             tag = d[self.tag]
         except KeyError:
-            raise DeserializationError(
-                'expected tag {!r}'.format(self.tag),
-                field=self
-            )
+            raise ValidationError(f'missing data, expected tag {self.tag!r}')
 
-        with map_errors(
-            DeserializationError,
-            value=tag,
-            field=self,
-            model_cls=model.__class__
-        ):
-            model.__class__ = self._deserialize(tag)
+        model.__class__ = self._deserialize(tag)
 
         return model, d
 
@@ -224,17 +176,7 @@ class Adjacent(Tag):
         Serialize the model variant by adjacently tagging the given dictionary.
         """
         variant = model.__class__
-
-        with map_errors(
-            SerializationError,
-            field=self,
-            model_cls=model.__class__
-        ):
-            d = OrderedDict([
-                (self.tag, self._serialize(variant)),
-                (self.content, d)
-            ])
-
+        d = OrderedDict([(self.tag, self._serialize(variant)), (self.content, d)])
         return d
 
     def _deserialize_with(self, model, d):
@@ -244,30 +186,16 @@ class Adjacent(Tag):
         try:
             tag = d[self.tag]
         except KeyError:
-            raise DeserializationError(
-                'expected tag {!r}'.format(self.tag),
-                field=self
-            )
+            raise ValidationError(f'missing data, expected tag {self.tag!r}')
 
         try:
             content = d[self.content]
         except KeyError:
-            raise DeserializationError(
-                'expected content {!r}'.format(self.content),
-                field=self
-            )
+            raise ValidationError(f'missing data, expected content {self.content!r}')
 
-        with map_errors(
-            DeserializationError,
-            field=self,
-            model_cls=model.__class__
-        ):
-            model.__class__ = self._deserialize(tag)
+        model.__class__ = self._deserialize(tag)
 
         return model, content
 
 
-__all__ = [
-    name for name, obj in globals().items()
-    if utils.is_subclass(obj, Tag)
-]
+__all__ = [name for name, obj in globals().items() if utils.is_subclass(obj, Tag)]
