@@ -4,39 +4,9 @@ This module defines some utility functions.
 
 import importlib
 from collections import OrderedDict
+from itertools import zip_longest
 
-from six.moves import zip_longest
-
-from serde.exceptions import MissingDependency
-
-
-def chained(funcs, value):
-    """
-    Chain multiple function calls, passing each result to the next function.
-
-    Arps:
-        funcs (iterable): the functions to chain.
-        value: the value to chain the functions on.
-
-    Returns:
-        the result of the chaining.
-    """
-    for func in funcs:
-        value = func(value)
-
-    return value
-
-
-def applied(funcs, value):
-    """
-    Call multiple functions on a single value.
-
-    Args:
-        funcs (iterable): the functions to apply.
-        value: the value to apply the functions to.
-    """
-    for func in funcs:
-        func(value)
+from serde.exceptions import MissingDependencyError
 
 
 def dict_partition(d, keyfunc, dict=OrderedDict):
@@ -55,13 +25,11 @@ def dict_partition(d, keyfunc, dict=OrderedDict):
     """
     left = dict()
     right = dict()
-
     for key, value in d.items():
         if keyfunc(key, value):
             left[key] = value
         else:
             right[key] = value
-
     return left, right
 
 
@@ -89,10 +57,8 @@ def subclasses(cls):
     """
     subs = cls.__subclasses__()
     variants = []
-
     for sub in subs:
         variants.extend(subclasses(sub))
-
     return subs + variants
 
 
@@ -107,21 +73,17 @@ def try_lookup(name):
         the object at the path.
 
     Raises:
-        serde.exceptions.MissingDepenency: if the path could not be imported.
+        serde.exceptions.MissingDependencyError: if the path could not be imported.
     """
     module, path = name.split('.', 1)
-
     try:
         obj = importlib.import_module(module)
     except ImportError:
-        raise MissingDependency(
-            "{!r} is missing, did you forget to install the 'ext' feature?"
-            .format(module)
+        raise MissingDependencyError(
+            f"{module!r} is missing, did you forget to install the serde 'ext' feature?"
         )
-
     for attr in path.split('.'):
         obj = getattr(obj, attr)
-
     return obj
 
 
@@ -139,11 +101,9 @@ def zip_equal(*iterables):
         ValueError: if one of the iterables is the wrong length.
     """
     sentinel = object()
-
     for element in zip_longest(*iterables, fillvalue=sentinel):
         if sentinel in element:
             raise ValueError('iterables have different lengths')
-
         yield element
 
 
@@ -163,12 +123,10 @@ def zip_until_right(*iterables):
     lefts = iterables[:-1]
     right = iter(iterables[-1])
     iterables = lefts + (right,)
-
     for item in zip(*iterables):
         yield item
-
     try:
         next(right)
-        raise ValueError('the rightmost iterable was not consumed')
+        raise ValueError('the right-most iterable was not consumed')
     except StopIteration:
         pass
